summaryrefslogtreecommitdiffhomepage
path: root/lib
diff options
context:
space:
mode:
authorJurriaan Pruis <[email protected]>2012-03-01 13:11:32 +0100
committerSean Duckett <[email protected]>2012-03-07 14:45:03 -0600
commit94f8dfd7645fa50be2a2f9c7f561a4ee22556001 (patch)
tree20bc9ffc0ef82cfbfc024289a65caaf01d05537e /lib
parentcf550ec678cb4c2c6e9b07102de4739735fac37e (diff)
downloadcaxlsx-94f8dfd7645fa50be2a2f9c7f561a4ee22556001.tar.gz
caxlsx-94f8dfd7645fa50be2a2f9c7f561a4ee22556001.zip
Accept row numbers in Worksheet#[]
Diffstat (limited to 'lib')
-rw-r--r--lib/axlsx/workbook/worksheet/worksheet.rb3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/axlsx/workbook/worksheet/worksheet.rb b/lib/axlsx/workbook/worksheet/worksheet.rb
index d1c8e6ac..68a3e3c6 100644
--- a/lib/axlsx/workbook/worksheet/worksheet.rb
+++ b/lib/axlsx/workbook/worksheet/worksheet.rb
@@ -112,9 +112,10 @@ module Axlsx
# Returns the cell or cells defined using excel style A1:B3 references.
# @param [String] cell_def the string defining the cell or range of cells
# @return [Cell, Array]
def [](cell_def)
+ return rows[cell_def - 1] if cell_def.is_a? Integer
parts = cell_def.split(':')
first = name_to_cell parts[0]
@@ -112,9 +112,10 @@ module Axlsx
# Returns the cell or cells defined using excel style A1:B3 references.
- # @param [String] cell_def the string defining the cell or range of cells
+ # @param [String|Integer] cell_def the string defining the cell or range of cells, or the rownumber
# @return [Cell, Array]
def [](cell_def)